import browserify from 'browserify';
import buffer     from 'vinyl-buffer';
import gulp       from 'gulp';
import sass       from 'gulp-sass';
import path       from 'path';
import rename     from 'gulp-rename';
import source     from 'vinyl-source-stream';
import sourcemaps from 'gulp-sourcemaps';

let browserSync = require('browser-sync').create();
let sassFiles   = './sass/**/*.scss';

gulp
  // JavaScript task.
  .task('js', () => {
    compileJS('hlt', './', './dist');
  })

  // BrowserSync task.
  .task('browser-sync', function() {
    return browserSync.init({
      // Use Canary.
      browser: 'Google Chrome Canary',
      // Make notification less intrusive.
      notify: {
        styles: {
          opacity: .5,
        },
      },
      // Serve from this dir.
      server: {
        baseDir: './',
      },
      // Move Browsersync snippet to end of file.
      snippetOptions: {
        rule: {
          match: /<\/body>/i,
          fn: function(snippet, match) {
            return snippet + match;
          },
        },
      },
    });
  })

  // Sass task.
  .task('sass', () => {
    return gulp.src(sassFiles)
      .pipe(sourcemaps.init())
      .pipe(sass.sync({
        includePaths: 'node_modules',
      }).on('error', sass.logError))
      .pipe(sourcemaps.write('./'))
      .pipe(gulp.dest('./dist'))
      // Inject styles with Browsersync.
      .pipe(browserSync.stream());
  })

  // Watch task.
  .task('watch', ['js', 'browser-sync'], () => {
    gulp.watch(sassFiles, ['sass']);
    gulp.watch('./hlt.js', ['js']);
    gulp.watch('./src/**/*', ['js']);
    gulp.watch(['./index.html', './dist/hlt.js'], browserSync.reload);
  });




/**
 * Compile JavaScript.
 *
 * @author Curtis Blackwell
 * @param  {String} filename
 * @param  {String} src      Path to the source file.
 * @param  {String} dest     Path where compiled file should save.
 * @return {Object}          Result of browerify.
 */
function compileJS(filename, src, dest) {
  let srcFile  = path.join(src, filename);

  return browserify({
      debug:     false,
      entries:   srcFile,
    }).bundle()
      .on('error', (error) => {
        throw new Error(error);
      })
      .pipe(source(srcFile))
      .pipe(buffer())
      // Make sure the file doesn't end up at some crazy path.
      .pipe(rename(filename + '.js'))
      .pipe(sourcemaps.init({loadMaps: true}))
      .pipe(sourcemaps.write('./'))
      .pipe(gulp.dest(dest));
};
